===============
django-pgallery
===============

.. image:: https://requires.io/github/zsiciarz/django-pgallery/requirements.svg?branch=master
    :target: https://requires.io/github/zsiciarz/django-pgallery/requirements/?branch=master
    :alt: Requirements Status

.. image:: https://img.shields.io/pypi/v/django-pgallery.svg
    :target: https://pypi.python.org/pypi/django-pgallery/
    :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/django-pgallery.svg
    :target: https://pypi.python.org/pypi/django-pgallery/
    :alt: Number of PyPI downloads

.. image:: https://img.shields.io/pypi/pyversions/django-pgallery.svg
    :target: https://pypi.python.org/pypi/django-pgallery/
    :alt: Supported Python versions

.. image:: https://img.shields.io/pypi/wheel/django-pgallery.svg
    :target: https://pypi.python.org/pypi/django-pgallery/
    :alt: Wheel Status

.. image:: https://travis-ci.org/zsiciarz/django-pgallery.svg?branch=master
    :target: https://travis-ci.org/zsiciarz/django-pgallery

.. image:: https://coveralls.io/repos/zsiciarz/django-pgallery/badge.png?branch=master
    :target: https://coveralls.io/r/zsiciarz/django-pgallery?branch=master


Photo gallery app for Django using PostgreSQL-specific goodies.

Overview
========

This is yet another Django app for creating and managing photos and photo
galleries, but with a PostgreSQL twist. It was made to show off some of the
advanced PostgreSQL features, therefore it is deliberately not portable
to other RDBMS-es.

Features
========

 * image tagging with array data type
 * storing EXIF data in HStore fields

Resources
---------

 * `Issue tracker <https://github.com/zsiciarz/django-pgallery/issues>`_

Author
======

 * Zbigniew Siciarz (zbigniew at siciarz dot net)

License
=======

This work is released under the MIT license. A copy of the license is provided
in the LICENSE file.

